from django.urls import reverse
from rest_framework import status
from rest_framework.test import (APIRequestFactory, APITestCase,
                                 force_authenticate)

from core.tests import data_factories
from core.views import StudentReviewerApiViewSet
from util.factories import GradyUserFactory


class StudentPageTests(APITestCase):

    @classmethod
    def setUpTestData(cls):
        cls.factory = APIRequestFactory()
        cls.user_factory = GradyUserFactory()

    def setUp(self):
        self.submission, _, _ = data_factories.make_minimal_exam()
        self.student = self.submission.student
        self.reviewer = self.user_factory.make_reviewer(username='reviewer')
        self.request = self.factory.get(reverse('student-list'))
        self.view = StudentReviewerApiViewSet.as_view({'get': 'list'})

        force_authenticate(self.request, user=self.reviewer.user)
        self.response = self.view(self.request)

    def test_can_access(self):
        self.assertEqual(self.response.status_code, status.HTTP_200_OK)

    def test_can_see_all_students(self):
        self.assertEqual(1, len(self.response.data))

    def test_submissions_score_is_included(self):
        self.assertEqual(self.student.submissions.first().feedback.score,
                         self.response.data[0]['submissions'][0]['score'])

    def test_submissions_full_score_is_included(self):
        self.assertEqual(self.student.submissions.first().type.full_score,
                         self.response.data[0]['submissions'][0]['full_score'])
